from typing import Iterator

import pytest
from openinference.instrumentation import suppress_tracing
from opentelemetry.context import (
    _SUPPRESS_INSTRUMENTATION_KEY,
    attach,
    detach,
    get_value,
    set_value,
)


def test_suppress_tracing(obj: object) -> None:
    with suppress_tracing():
        assert get_value(_SUPPRESS_INSTRUMENTATION_KEY) is True
    assert get_value(_SUPPRESS_INSTRUMENTATION_KEY) is obj


@pytest.fixture(autouse=True)
def instrument(obj: object) -> Iterator[None]:
    token = attach(set_value(_SUPPRESS_INSTRUMENTATION_KEY, obj))
    yield
    detach(token)


@pytest.fixture
def obj() -> object:
    return object()



import contextlib
from typing import Iterator


@contextlib.contextmanager
def suppress_tracing() -> Iterator[None]:
    """
    Context manager to pause OpenTelemetry instrumentation.

    Examples:
        with suppress_tracing():
            # No tracing will occur within this block
            ...
    """
    try:
        from opentelemetry.context import _SUPPRESS_INSTRUMENTATION_KEY, attach, detach, set_value
    except ImportError:
        yield
        return
    token = attach(set_value(_SUPPRESS_INSTRUMENTATION_KEY, True))
    yield
    detach(token)
